import youtube_dl
import pandas as pd
import jellyfish
import logging


YDL_OPTIONS = {'format': 'bestaudio', 'noplaylist':'True'}
YOUTUBE_URL_KEY = 'webpage_url'

def get_youtube_from_isrc(isrc: str):
    # https://stackoverflow.com/questions/63388364/searching-youtube-videos-using-youtube-dl
    with youtube_dl.YoutubeDL(YDL_OPTIONS) as ydl:
        video = ydl.extract_info(f"ytsearch:{isrc}", download=False)['entries'][0]
    print(type(video))
    if YOUTUBE_URL_KEY not in video:
        return None
    return {
        'url': video[YOUTUBE_URL_KEY],
        'title': video['title']
    }

def get_youtube_url(row):
    if pd.isna(row['isrc']):
        return None
    real_title = row['title'].lower()

    result = get_youtube_from_isrc(row['isrc'])
    video_title = result['title'].lower()

    phonetic_distance = jellyfish.levenshtein_distance(real_title, video_title)

    print(real_title, video_title, phonetic_distance)
    if phonetic_distance > 1:
        logging.warning(f"dont downloading {result['url']} cuz the phonetic distance ({phonetic_distance}) between {real_title} and {video_title} is to high.")
        return None
    return result['url']

def download(row):
    url = row['url']
    file_ = row['file']
    options = {
        'format': 'bestaudio/best',
        'postprocessors': [{
            'key': 'FFmpegExtractAudio',
            'preferredcodec': 'mp3',
            'preferredquality': '192',
        }],
        'keepvideo': False,
        'outtmpl': file_
    }

    with youtube_dl.YoutubeDL(options) as ydl:
        ydl.download([url])

if __name__ == "__main__":
    # example isrc that exists on youtube music
    ISRC = "DEUM71500715"
    result = get_youtube_from_isrc(ISRC)
    print(result)
    result = get_youtube_from_isrc("aslhfklasdhfjklasdfjkhasdjlfhlasdjfkuuiueiw")
    print(result)
